[Rt-commit] rt branch, 4.0/interface-in-headers, updated. rt-4.0.6-235-gf39d2a0

Alex Vandiver alexmv at bestpractical.com
Fri Nov 2 19:20:48 EDT 2012


The branch, 4.0/interface-in-headers has been updated
       via  f39d2a0eec75b2411c7f6ca1e9520fbe332b9593 (commit)
       via  ff7e413261a02bfba66f6dfc304162050d6a9715 (commit)
      from  9189e6989c6a78aa52b024e0027be2e04217aeb6 (commit)

Summary of changes:
 lib/RT/Interface/Web.pm | 3 ++-
 lib/RT/Ticket.pm        | 3 +++
 2 files changed, 5 insertions(+), 1 deletion(-)

- Log -----------------------------------------------------------------
commit ff7e413261a02bfba66f6dfc304162050d6a9715
Author: Alex Vandiver <alexmv at bestpractical.com>
Date:   Fri Nov 2 19:18:41 2012 -0400

    Ensure that attachments don't get an X-RT-Interface forced on them

diff --git a/lib/RT/Ticket.pm b/lib/RT/Ticket.pm
index 306ad4a..ddb3d8b 100644
--- a/lib/RT/Ticket.pm
+++ b/lib/RT/Ticket.pm
@@ -2228,6 +2228,9 @@ sub _RecordNote {
         );
     }
 
+    $args{'MIMEObj'}->head->replace('X-RT-Interface' => 'API')
+        unless $args{'MIMEObj'}->head->get('X-RT-Interface');
+
     # convert text parts into utf-8
     RT::I18N::SetMIMEEntityToUTF8( $args{'MIMEObj'} );
 

-----------------------------------------------------------------------


More information about the Rt-commit mailing list
diff --git a/lib/RT/Interface/Web.pm b/lib/RT/Interface/Web.pm
index 8e209a4..46d4126 100644
--- a/lib/RT/Interface/Web.pm
+++ b/lib/RT/Interface/Web.pm
@@ -1987,8 +1987,9 @@ sub MakeMIMEEntity {
                 $Message->head->set( 'Subject' => $filename );
             }
 
             # Attachment parts really shouldn't get a Message-ID
             $Message->head->delete('Message-ID');
+            $Message->head->delete('X-RT-Interface');
         }
     }
 
@@ -1987,8 +1987,9 @@ sub MakeMIMEEntity {
             }
 
-            # Attachment parts really shouldn't get a Message-ID
+            # Attachment parts really shouldn't get a Message-ID or "interface"
             $Message->head->delete('Message-ID');

commit f39d2a0eec75b2411c7f6ca1e9520fbe332b9593
Author: Alex Vandiver <alexmv at bestpractical.com>
Date:   Fri Nov 2 19:20:16 2012 -0400

    Give any MIMEObjs (via Content, for example) a default X-RT-Interface
